@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Mojolicious::Plugin::Web::Auth::Site::Reddit;
-$Mojolicious::Plugin::Web::Auth::Site::Reddit::VERSION = '0.000002';
+$Mojolicious::Plugin::Web::Auth::Site::Reddit::VERSION = '0.000003';
 use Mojo::Base qw/Mojolicious::Plugin::Web::Auth::OAuth2/;
 
 has access_token_url => 'https://www.reddit.com/api/v1/access_token';
@@ -26,7 +26,7 @@ Mojolicious::Plugin::Web::Auth::Site::Reddit - Reddit OAuth Plugin for Mojolicio
 
 =head1 VERSION
 
-version 0.000002
+version 0.000003
 
 =head1 SYNOPSIS
 
@@ -55,7 +55,7 @@ version 0.000002
         secret      => 'Reddit consumer secret',
         scope       => $scope,
         on_finished => sub {
-            my ( $c, $access_token, $access_secret ) = @_;
+            my ( $c, $access_token, $access_secret, $extra ) = @_;
             ...;
         },
     );
@@ -70,7 +70,7 @@ version 0.000002
         secret      => 'Reddit consumer secret',
         scope       => $scope,
         on_finished => sub {
-            my ( $c, $access_token, $access_secret ) = @_;
+            my ( $c, $access_token, $access_secret, $extra ) = @_;
             ...
         };
 
@@ -84,7 +84,16 @@ L<Mojolicious::Plugin::Web::Auth>.
 
 The default C<authorize_url> allows only for temporary tokens.  If you require
 a refresh token, set your own C<authorize_url> as in the example in the
-SYNOPSIS.
+SYNOPSIS.  Your C<refresh_token> will be included in the C<$extra> arg as seen
+above.  For example, C<$extra> may look like the following:
+
+    {
+        expires_in    => 3600,
+        refresh_token => 'seekrit_token',
+        scope =>
+            'edit flair history identity modconfig modflair modlog modposts modwiki mysubreddits privatemessages read report save submit subscribe vote wikiedit wikiread',
+        token_type => 'bearer',
+    },
 
 =head1 AUTHOR
 
